==> lsof_3.65.orig.tar.gz: lsof-3.65.orig/dialects/freebsd/dstore.c <==
/*
 * dstore.c - FreeBSD global storage for lsof
 */


/*
 * Copyright 1994 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */

#ifndef lint
static char copyright[] =
"@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
static char *rcsid = "$Id: dstore.c,v 1.5 95/07/20 12:37:04 abe Exp $";
#endif


#include "lsof.h"

#if	_FREEBSDV>=200
kvm_t *Kd = NULL;			/* kvm descriptor */
#endif	/* _FREEBSDV>=200 */

struct l_vfs *Lvfs = NULL;		/* local vfs structure table */

struct nlist Nl[] = {

#if	_FREEBSDV<205
	{ "_nchhead"    },
#else	/* _FREEBSDV>=205 */
	{ "_nclruhead"  },
#endif	/* _FREEBSDV<205 */

	{ "_numcache"   },
	{ ""            }
};

int Np = 0;				/* number of kernel processes */

#if	_FREEBSDV>=200
struct kinfo_proc *P = NULL;		/* local process table copy */
#endif	/* _FREEBSDV>=200 */

==> lsof_4.28.orig.tar.gz: lsof-4.28.orig/dialects/freebsd/dstore.c <==
/*
 * dstore.c - FreeBSD global storage for lsof
 */


/*
 * Copyright 1994 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */

#ifndef lint
static char copyright[] =
"@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
static char *rcsid = "$Id: dstore.c,v 1.2 97/05/30 16:31:43 abe Exp $";
#endif


#include "lsof.h"

struct file *Cfp;			/* curent file's file struct pointer */


/*
 * Drive_Nl -- table to drive the building of Nl[] via build_Nl()
 *             (See lsof.h and misc.c.)
 */

struct drive_Nl Drive_Nl[] = {

#if	FREEBSDV<205
	{ X_NCACHE,	"_nchhead"	},
#else	/* FREEBSDV>=205 */
# if	FREEBSDV<210
	{ X_NCACHE,	"_nclruhead"	},
# else	/* FREEBSDV>=210 */
	{ X_NCACHE,	"_nchashtbl"	},
# endif	/* FREEBSDV<210 */
#endif	/* FREEBSDV<205 */

#if	FREEBSDV<210
	{ X_NCSIZE,	"_numcache"	},
#else	/* FREEBSDV>=210 */
	{ X_NCSIZE,	"_nchash"	},
#endif	/* FREEBSDV<210 */

	{ "",		""		},
	{ NULL,		NULL		}
};

#if	FREEBSDV>=200
kvm_t *Kd = NULL;			/* kvm descriptor */
#endif	/* FREEBSDV>=200 */

#if	defined(P_ADDR)
KA_T Kpa;				/* kernel proc struct address */
#endif	/* defined(P_ADDR) */

struct l_vfs *Lvfs = NULL;		/* local vfs structure table */

int Np = 0;				/* number of kernel processes */

#if	FREEBSDV>=200
struct kinfo_proc *P = NULL;		/* local process table copy */
#endif	/* FREEBSDV>=200 */
